@@ -22,7 +22,9 @@ WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,
 ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS
 SOFTWARE.
 
-3D extensions added : Roland Krause 1996
+3D extensions added :			Roland Krause 1996
+Data type for system time changed
+from long to the correct type 'time_t':	Roland Krause 1999
 
 ******************************************************************/
 
@@ -43,8 +45,8 @@ SOFTWARE.
 extern struct tm *localtime();
 #endif
 
-static void clock_tic(), DrawHand(), DrawSecond(), SetSeg(), DrawClockFace();
-static erase_hands(), round();
+static void clock_tic(), erase_hands(), DrawHand(), DrawSecond(), SetSeg(), DrawClockFace();
+static int round();
 	
 /* Private Definitions */
 
@@ -183,7 +185,7 @@ static void Initialize (request, new)
     if(!w->clock.analog) {
        char *str;
        struct tm tm;
-       long time_value;
+       time_t time_value;
        (void) time(&time_value);
        tm = *localtime(&time_value);
        str = asctime(&tm);
@@ -307,7 +309,7 @@ static void clock_tic(client_data, id)
 {
         ClockWidget w = (ClockWidget)client_data;    
 	struct tm tm; 
-	long	time_value;
+	time_t   time_value;
 	char	*time_ptr;
         register Display *dpy = XtDisplay(w);
         register Window win = XtWindow(w);
@@ -447,7 +449,7 @@ static void clock_tic(client_data, id)
 		}
 }
 	
-static erase_hands (w, tm)
+static void erase_hands(w, tm)
 ClockWidget	w;
 struct tm	*tm;
 {
