@@ -78,8 +78,9 @@ static XtResource resources[] = {
 #undef offset
 
 static Boolean SetValues();
-static void Initialize(), Redisplay(), Set(), Reset(), Notify(), Unset();
-static void Highlight(), Unhighlight(), Destroy(), PaintCommandWidget(), Resize();
+static void Initialize(), Redisplay(), Set(), Reset(), Notify(), Unset(),
+	    Highlight(), Unhighlight(), Destroy(), PaintCommandWidget(),
+	    Resize(), RepositionLabel();
 static XtGeometryResult QueryGeometry();
 
 static XtActionsRec actionsList[] = {
@@ -173,6 +174,91 @@ Region region;
   }
 }
 
+/***********************************************************************
+ *
+ * CalcWidth,		Calculate the required width and height of
+ * CalcHeight:		the Command widget.
+ *	Arguments: 	w - the command widget.
+ *	Returns:	The required width or height
+ *
+ *
+ ***********************************************************************/
+
+static Dimension CalcWidth(cbw)
+CommandWidget cbw;
+{
+  return(LEFT_OFFSET(cbw) + cbw->label.label_width +
+	 2*(cbw->label.internal_width + cbw->command.highlight_thickness +
+	   cbw->add3dExt.borderWidth));
+}
+
+static Dimension CalcHeight(cbw)
+CommandWidget cbw;
+{
+  return(cbw->label.label_height + 2*(cbw->label.internal_height +
+	 cbw->command.highlight_thickness + cbw->add3dExt.borderWidth));
+}
+
+/***********************************************************************
+ *
+ * RepositionLabel:	Calculate the correct position of the label
+ *			or bitmap and the left bitmap.
+ *	Arguments: 	current	- the current command widget
+ *			new	- The new widget with its resources
+ *
+ *	Returns:	none
+ *
+ ***********************************************************************/
+
+static void RepositionLabel(current, new)
+Widget current, new;
+{
+  CommandWidget cbw = (CommandWidget)new;
+  Position newPos, leftedge;
+
+  leftedge = LEFT_OFFSET(cbw) + cbw->label.internal_width +
+	     cbw->command.highlight_thickness + cbw->add3dExt.borderWidth;
+  switch (cbw->label.justify) {
+
+	case XtJustifyLeft:
+	    newPos = leftedge;
+	    break;
+
+	case XtJustifyRight:
+	    newPos = current->core.width - cbw->label.label_width - cbw->label.internal_width -
+		     cbw->command.highlight_thickness - cbw->add3dExt.borderWidth;
+	    break;
+
+	case XtJustifyCenter:
+	default:
+	    newPos = (Position)((current->core.width - cbw->label.label_width)/2);
+	    break;
+  }
+  /* Justify the label on the left side, if there is not enough space
+   * in the widget. Don't do that with pixmaps.
+   */
+  if ((newPos < leftedge) && (cbw->label.pixmap == None)) newPos = leftedge;
+  cbw->label.label_x = newPos;
+  cbw->label.label_y = (int)(current->core.height - cbw->label.label_height)/2;
+
+    /*
+     * Left bitmap will be displayed at
+     * (internal_width + border width, internal_height + border height + lbm_y)
+     */
+    if (cbw->label.lbm_height != 0)
+    {
+	cbw->label.lbm_y = (int)((current->core.height - cbw->label.lbm_height)/2 -
+			         cbw->label.internal_height);
+	cbw->label.lbm_x = (int)(cbw->label.internal_width + cbw->command.highlight_thickness +
+				 cbw->add3dExt.borderWidth);
+    }
+    else
+    {
+	cbw->label.lbm_y = 0;
+	cbw->label.lbm_x = 0;
+    }
+}
+
 /***********************************************************************
  *
  * DestroyHelpWidget:	Destroy the not longer required helper widget
@@ -274,17 +360,16 @@ ArgList args;			/* unused */
 Cardinal *num_args;		/* unused */
 {
   Dimension Add;
-
-  CommandWidget cbw = (CommandWidget) new;
+  CommandWidget cbw = (CommandWidget)new;
 
   cbw->command.set = FALSE;
 
-  /* Resize the underlying label widget */
+  /* Calculate the correct size of the widget */
 
   Add = 2 * (cbw->add3dExt.borderWidth + cbw->command.highlight_thickness);
   cbw->core.width  += Add;
   cbw->core.height += Add;
-  (*commandWidgetClass->core_class.superclass->core_class.resize)(new);
+  RepositionLabel(new, new);
 
   /* Initialize the help widget, if required */
 
@@ -322,6 +407,27 @@ Widget w;
    DestroyHelpWidget(cbw);
 }
 
+/***********************************************************************
+ *
+ * Resize method:	Resize the underlying label widget and paint
+ *			the own decorations.
+ *
+ ***********************************************************************/
+
+static void Resize(w)
+Widget w;
+{
+  CommandWidget cbw = (CommandWidget)w;
+  int offset         = (int)cbw->command.highlight_thickness;
+  unsigned int width = w->core.width - 2*offset;
+  unsigned int height= w->core.height - 2*offset;
+
+  RepositionLabel(w, w);
+
+  if (XtIsRealized(w) && (cbw->command.highlightMode == FALSE)) 
+    XawRaisedRectangle(w, offset, offset, width, height);
+}
+
 /***********************************************************************
  *
  * Set Values method:	Set specified arguments into widget
@@ -333,9 +439,8 @@ Widget current, request, new;
 ArgList args;
 Cardinal *num_args;
 {
-  CommandWidget oldcbw = (CommandWidget) current;
-  CommandWidget cbw = (CommandWidget) new;
-  Dimension     Add;
+  CommandWidget oldcbw = (CommandWidget)current;
+  CommandWidget cbw = (CommandWidget)new;
   Boolean	redisplay = FALSE,
 		NoWidthArg = TRUE, NoHeightArg = TRUE, DoResize = FALSE;
   int		i;
@@ -366,6 +471,8 @@ Cardinal *num_args;
 	CreateHelpWidget(cbw);
     }
   }
+  if (oldcbw->command.highlight_thickness != cbw->command.highlight_thickness)
+    DoResize = TRUE;
 
   if ( oldcbw->core.sensitive != cbw->core.sensitive && !cbw->core.sensitive)
   {
@@ -373,9 +480,6 @@ Cardinal *num_args;
     redisplay = TRUE;
   }
   
-  if (oldcbw->command.highlight_thickness != cbw->command.highlight_thickness)
-    DoResize = TRUE;
-
   if (oldcbw->command.highlightMode != cbw->command.highlightMode)
     redisplay = TRUE;
 
@@ -387,47 +491,26 @@ Cardinal *num_args;
     if (strcmp(XtNwidth, args[i].name) == 0) NoWidthArg = FALSE;
     if (strcmp(XtNheight, args[i].name) == 0) NoHeightArg = FALSE;
   }
-  Add = 2 * (cbw->add3dExt.borderWidth + cbw->command.highlight_thickness);
-  if ((oldcbw->core.width > cbw->core.width) && NoWidthArg)
+
+  if ((oldcbw->core.width != cbw->core.width) && NoWidthArg)
   {
-    cbw->core.width += Add;
+    cbw->core.width = CalcWidth(cbw);
     DoResize = TRUE;
   }
-  if ((oldcbw->core.height > cbw->core.height) && NoHeightArg)
+  if ((oldcbw->core.height != cbw->core.height) && NoHeightArg)
   {
-    cbw->core.height += Add;
+    cbw->core.height = CalcHeight(cbw);
     DoResize = TRUE;
   }
   if (DoResize)
   {
-    (*commandWidgetClass->core_class.superclass->core_class.resize)(new);
+    RepositionLabel(current, new);
     redisplay = TRUE;
   }
 
   return (redisplay);
 }
 
-/***********************************************************************
- *
- * Resize method:	Resize the underlying label widget and paint
- *			the own decorations.
- *
- ***********************************************************************/
-
-static void Resize(w)
-Widget w;
-{
-  CommandWidget cbw = (CommandWidget)w;
-  int offset         = (int)cbw->command.highlight_thickness;
-  unsigned int width = w->core.width - 2*offset;
-  unsigned int height= w->core.height - 2*offset;
-
-  (*commandWidgetClass->core_class.superclass->core_class.resize)(w);
-
-  if (XtIsRealized(w) && (cbw->command.highlightMode == FALSE)) 
-    XawRaisedRectangle(w, offset, offset, width, height);
-}
-
 /***********************************************************************
  *
  *  Action Procedures
