@@ -770,15 +770,13 @@ static XtGeometryResult PreferredGeometry( widget, request, reply  )
     reply->width = w->form.preferred_width;
     reply->height = w->form.preferred_height;
     reply->request_mode = CWWidth | CWHeight;
-    if (  request->request_mode & (CWWidth | CWHeight) ==
-	    (CWWidth | CWHeight)
-	  && request->width == reply->width
-	  && request->height == reply->height)
-	return XtGeometryYes;
-    else if (reply->width == w->core.width && reply->height == w->core.height)
-	return XtGeometryNo;
+    if ((request->request_mode & (CWWidth|CWHeight)) == (CWWidth|CWHeight) &&
+	(request->width == reply->width) && (request->height == reply->height))
+      return XtGeometryYes;
+    else if ((reply->width == w->core.width) && (reply->height == w->core.height))
+      return XtGeometryNo;
     else
-	return XtGeometryAlmost;
+      return XtGeometryAlmost;
 }
 
 
