@@ -307,25 +307,28 @@ static void GetgrayGCs(lw)
 
 }
 
-static void compute_bitmap_offsets (lw)
-    LabelWidget lw;
+static void compute_bitmap_offsets(clw, lw)
+LabelWidget lw, clw;
 {
     /*
      * label will be displayed at (internal_width, internal_height + lbm_y)
      */
     if (lw->label.lbm_height != 0) {
-	lw->label.lbm_y = (((int) lw->core.height) -
+	lw->label.lbm_y = (((int)clw->core.height) -
 			   ((int) lw->label.internal_height * 2) -
 			   ((int) lw->label.lbm_height)) / 2;
-    } else {
+        lw->label.lbm_x = (int) lw->label.internal_width;
+    }
+    else {
 	lw->label.lbm_y = 0;
+    	lw->label.lbm_x = 0;
     }
 }
 
 /* Check if bitmaps or pixmaps in use and determine width, height and depth
  */
-static void set_bitmap_info(lw)
-LabelWidget lw;
+static void set_bitmap_info(clw, lw)
+LabelWidget clw, lw;
 {
     Window root;
     int x, y;
@@ -336,7 +339,7 @@ LabelWidget lw;
 	      &lw->label.lbm_width, &lw->label.lbm_height, &bw, &lw->label.label_depth))) {
 	lw->label.lbm_width = lw->label.lbm_height = 0;
     }
-    compute_bitmap_offsets(lw);
+    compute_bitmap_offsets(clw, lw);
 }
 
 /***********************************************************************
@@ -390,7 +393,7 @@ static void Initialize(request, new)
     if (lw->core.height == 0)
         lw->core.height = lw->label.label_height + 2*lw->label.internal_height;
 
-    set_bitmap_info (lw);		/* need core.height */
+    set_bitmap_info(lw, lw);		/* need core.height */
 
     if (lw->core.width == 0)		/* need label.lbm_width */
         lw->core.width = (lw->label.label_width + 2 * lw->label.internal_width
@@ -472,18 +475,18 @@ Region region;
 	 if (lw->label.label_depth == 1)
 	   XCopyPlane(XtDisplay(w), lw->label.left_bitmap, XtWindow(w), gc,
 		       0, 0, lw->label.lbm_width, lw->label.lbm_height,
-		       (int) lw->label.internal_width, 
+		       (int) lw->label.lbm_x, 
 		       (int) lw->label.internal_height + lw->label.lbm_y,
 		       (unsigned long) 1L);
          else {
 	   if (lw->label.xpm_clipmask != None) {
 	     XSetClipMask(XtDisplay(w), gc, lw->label.xpm_clipmask);
-	     XSetClipOrigin(XtDisplay(w), gc, lw->label.internal_width,
+	     XSetClipOrigin(XtDisplay(w), gc, lw->label.lbm_x,
 			    lw->label.internal_height + lw->label.lbm_y);
 	   }
 	   XCopyArea(XtDisplay(w), lw->label.left_bitmap, XtWindow(w), gc,
 		       0, 0, lw->label.lbm_width, lw->label.lbm_height,
-		       (int) lw->label.internal_width, 
+		       (int) lw->label.lbm_x, 
 		       (int) lw->label.internal_height + lw->label.lbm_y);
 	   XSetClipMask(XtDisplay(w), gc, None);
          }
@@ -503,7 +506,7 @@ Region region;
        }
        if (len) _DrawLabelString(lw, label, (int)y, len);
    }
-   else	/* Label with bitmap or pixmap */
+   else	/* Label with only a bitmap or pixmap */
    {
       if (lw->label.label_depth == 1)
         XCopyPlane(XtDisplay(w), lw->label.pixmap, XtWindow(w), gc,
@@ -563,7 +566,7 @@ static void Resize(w)
     LabelWidget lw = (LabelWidget)w;
 
     _Reposition(lw, w->core.width, w->core.height);
-    compute_bitmap_offsets (lw);
+    compute_bitmap_offsets(lw, lw);
 }
 
 /***********************************************************************
@@ -626,7 +629,7 @@ static Boolean SetValues(current, request, new, args, num_args)
       if ((curlw->core.height == reqlw->core.height) && !checks[HEIGHT])
 	newlw->core.height = newlw->label.label_height + 2 * newlw->label.internal_height;
 
-	set_bitmap_info (newlw);
+	set_bitmap_info(curlw, newlw);
 
 	if ((curlw->core.width == reqlw->core.width) && !checks[WIDTH])
 	    newlw->core.width = newlw->label.label_width + LEFT_OFFSET(newlw) +
