@@ -31,6 +31,8 @@
 #include <sys/stat.h>			/* for stat() ** needs types.h ***/
 #include <stdio.h>			/* for printing error messages */
 #include <pwd.h>			/* for getting username */
+#include <stdlib.h>
+#include <unistd.h>
 
 #ifndef X_NOT_POSIX
 #ifdef _POSIX_SOURCE
