@@ -34,7 +34,7 @@
 #include <X11/XawPlus/PannerP.h>	/* us */
 #include <X11/Xmu/Misc.h>		/* for Min */
 #include <ctype.h>			/* for isascii() etc. */
-#include <math.h>			/* for atof() */
+#include <stdlib.h>			/* for atof() */
 
 #if defined(ISC) && defined(SYSV) && defined(SYSV386) && __STDC__
 extern double atof(char *);
@@ -56,7 +56,7 @@ static char defaultTranslations[] =
 
 
 static void ActionStart(), ActionStop(), ActionAbort(), ActionMove();
-static void ActionPage(), ActionNotify(), ActionSet();
+static void ActionPage(), ActionNotify();
 
 static XtActionsRec actions[] = {
     { "start", ActionStart },		/* start tmp graphics */
@@ -374,8 +374,6 @@ static void Realize (gw, valuemaskp, attr)
     XtValueMask *valuemaskp;
     XSetWindowAttributes *attr;
 {
-    PannerWidget pw = (PannerWidget) gw;
-
     (*pannerWidgetClass->core_class.superclass->core_class.realize)(gw, valuemaskp, attr);
 }
 
