@@ -487,7 +487,7 @@ Cardinal *num_args;
 }
 
 /*      Function Name: SetValuesHook
-/*      Description: To handle a special case, this is passed the
+ *      Description: To handle a special case, this is passed the
  *                   actual arguments.
  *      Arguments: w - the menu widget.
  *                 arglist - the argument list passed to XtSetValues.
@@ -1261,7 +1261,7 @@ XEvent * event;
     default:
 	XtAppError(XtWidgetToApplicationContext(w),
 		   "Unknown event type in GetEventEntry().");
-	break;
+	return(NULL);
     }
     
     if ( (x_loc < 0) || (x_loc >= (int)smw->core.width) || (y_loc < 0) ||
