@@ -778,7 +778,8 @@ Position *x, *y;
   *line = 0;
   *x = ctx->text.margin.left;
   *y = ctx->text.margin.top;
-  if (visible = IsPositionVisible(ctx, pos)) {
+  visible = IsPositionVisible(ctx, pos);
+  if (visible) {
     *line = LineForPosition(ctx, pos);
     *y = ctx->text.lt.info[*line].y;
     *x = ctx->text.margin.left;
@@ -1212,7 +1213,7 @@ XtPointer closure, callData; /* closure = TextWidget, callData = percent. */
   new_left -= (Position) (*percent * GetWidestLine(ctx));
   move = old_left - new_left;
 
-  if (abs(move) < (int)ctx->core.width) {
+  if (abs(move) < (int)(ctx->core.width)) {
     HScroll(w, (XtPointer) ctx, (XtPointer) move);
     return;
   }
@@ -2457,7 +2458,7 @@ Region region;			/* Unused. */
  * This routine does all setup required to syncronize batched screen updates
  */
 
-_XawTextPrepareToUpdate(ctx)
+void _XawTextPrepareToUpdate(ctx)
 TextWidget ctx;
 {
   if (ctx->text.old_insert < 0) {
@@ -2517,7 +2518,7 @@ TextWidget ctx;
  * generalization to allow more options.
  */
 
-_XawTextShowPosition(ctx)
+void _XawTextShowPosition(ctx)
 TextWidget ctx;
 {
   int x, y, lines, number;
