@@ -35,14 +35,14 @@ SOFTWARE.
  *						Chris D. Peterson     
  *						MIT X Consortium 
  */
-
+#include <stdio.h>
+#include <ctype.h>
+#include <stdlib.h>
 #include <X11/IntrinsicP.h>
 #include <X11/StringDefs.h>
 #include <X11/Xatom.h>
 #include <X11/Xmu/Misc.h>
 #include <X11/XawPlus/TextP.h>
-#include <stdio.h>
-#include <ctype.h>
 
 #define SrcScan                XawTextSourceScan
 #define FindDist               XawTextSinkFindDistance
@@ -186,7 +186,8 @@ Cardinal num_params;
 	int fmt8 = 8;
 	Atom type = XA_STRING;
 	char *line = XFetchBuffer(XtDisplay(w), &nbytes, buffer);
-	if (length = nbytes)
+	length = nbytes;
+	if (length > 0)
 	    _SelectionReceived(w, NULL, &selection, &type, (caddr_t)line,
 			       &length, &fmt8);
 	else if (num_params > 1)
@@ -941,7 +942,7 @@ Cardinal *num_params;
     for (sel=selections; --num_atoms >= 0; sel++, params++)
 	*sel = XInternAtom(dpy, *params, False);
     num_atoms = *num_params;
-    _XawTextSaltAwaySelection (w, selections, num_atoms);
+    _XawTextSaltAwaySelection ((TextWidget)w, selections, num_atoms);
     EndAction (w);
 }
 
